Contributing to NengoDL
=======================

Issues and pull requests are always welcome! We appreciate help from the
community to make NengoDL better.

Filing issues
-------------

If you find a bug in NengoDL, or think that a certain feature is missing,
please consider `filing an issue <https://github.com/nengo/nengo-dl/issues>`_.
Please search the currently open issues first to see if your bug or feature
request already exists. If so, feel free to add a comment to the issue
so that we know that multiple people are affected.

Making pull requests
--------------------

If you want to fix a bug or add a feature to NengoDL, we welcome pull requests.
We try to maintain 100% test coverage, so any new features should also include
unit tests to cover that change.  If you fix a bug it's also a good idea to
add a unit test, so that the bug doesn't get un-fixed in the future!

Contributor agreement
---------------------

We require that all contributions be covered under our contributor assignment
agreement. Please see `the agreement <https://www.nengo.ai/caa.html>`_
for instructions on how to sign.
